package xhttp3.internal.io;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import xio.Okio;
import xio.Sink;
import xio.Source;

public interface FileSystem {
   FileSystem SYSTEM = new FileSystem() {
      public Source source(File file) {
         return Okio.source(file);
      }

      public Sink sink(File file) {
         try {
            return Okio.sink(file);
         } catch (FileNotFoundException var2) {
            file.getParentFile().mkdirs();
            return Okio.sink(file);
         }
      }

      public Sink appendingSink(File file) {
         try {
            return Okio.appendingSink(file);
         } catch (FileNotFoundException var2) {
            file.getParentFile().mkdirs();
            return Okio.appendingSink(file);
         }
      }

      public void delete(File file) {
         if (!file.delete() && file.exists()) {
            throw new IOException("failed to delete " + file);
         }
      }

      public boolean exists(File file) {
         return file.exists();
      }

      public long size(File file) {
         return file.length();
      }

      public void rename(File from, File to) {
         this.delete(to);
         if (!from.renameTo(to)) {
            throw new IOException("failed to rename " + from + " to " + to);
         }
      }

      public void deleteContents(File directory) {
         File[] var2;
         if ((var2 = directory.listFiles()) != null) {
            int directory1 = var2.length;

            for(int var3 = 0; var3 < directory1; ++var3) {
               File var4;
               if ((var4 = var2[var3]).isDirectory()) {
                  this.deleteContents(var4);
               }

               if (!var4.delete()) {
                  throw new IOException("failed to delete " + var4);
               }
            }

         } else {
            throw new IOException("not a readable directory: " + directory);
         }
      }
   };

   Source source(File var1);

   Sink sink(File var1);

   Sink appendingSink(File var1);

   void delete(File var1);

   boolean exists(File var1);

   long size(File var1);

   void rename(File var1, File var2);

   void deleteContents(File var1);
}
